=========================
Orange Visual Programming
=========================

Getting Started
===============

Here we need to copy the getting started guide.

.. toctree::
   :maxdepth: 1

   loading-your-data/index


Widgets
=======

Data
----

.. toctree::
   :maxdepth: 1

   widgets/data/file
   widgets/data/datasets
   widgets/data/sqltable
   widgets/data/save
   widgets/data/datainfo
   widgets/data/datatable
   widgets/data/selectcolumns
   widgets/data/selectrows
   widgets/data/datasampler
   widgets/data/transpose
   widgets/data/discretize
   widgets/data/continuize
   widgets/data/createclass
   widgets/data/randomize
   widgets/data/concatenate
   widgets/data/paintdata
   widgets/data/pythonscript
   widgets/data/featureconstructor
   widgets/data/editdomain
   widgets/data/imageviewer
   widgets/data/impute
   widgets/data/mergedata
   widgets/data/outliers
   widgets/data/preprocess
   widgets/data/purgedomain
   widgets/data/rank
   widgets/data/color


Visualize
---------

.. toctree::
   :maxdepth: 1

   widgets/visualize/boxplot
   widgets/visualize/distributions
   widgets/visualize/heatmap
   widgets/visualize/scatterplot
   widgets/visualize/venndiagram
   widgets/visualize/linearprojection
   widgets/visualize/scattermap
   widgets/visualize/sievediagram
   widgets/visualize/pythagoreantree
   widgets/visualize/pythagoreanforest
   widgets/visualize/cn2ruleviewer
   widgets/visualize/mosaicdisplay
   widgets/visualize/silhouetteplot
   widgets/visualize/treeviewer
   widgets/visualize/geomap
   widgets/visualize/nomogram


Model
-----

.. toctree::
   :maxdepth: 1

   widgets/model/constant
   widgets/model/cn2ruleinduction
   widgets/model/knn
   widgets/model/tree
   widgets/model/randomforest
   widgets/model/svm
   widgets/model/linearregression
   widgets/model/logisticregression
   widgets/model/naivebayes
   widgets/model/adaboost
   widgets/model/neuralnetwork
   widgets/model/stochasticgradient
   widgets/model/loadmodel
   widgets/model/savemodel


Unsupervised
------------

.. toctree::
   :maxdepth: 1

   widgets/unsupervised/PCA
   widgets/unsupervised/correspondenceanalysis
   widgets/unsupervised/distancemap
   widgets/unsupervised/distances
   widgets/unsupervised/distancematrix
   widgets/unsupervised/distancetransformation
   widgets/unsupervised/distancefile
   widgets/unsupervised/savedistancematrix
   widgets/unsupervised/hierarchicalclustering
   widgets/unsupervised/kmeansclustering
   widgets/unsupervised/mds
   widgets/unsupervised/manifoldlearning
   

Evaluation
----------

.. toctree::
   :maxdepth: 1

   widgets/evaluation/calibrationplot
   widgets/evaluation/confusionmatrix
   widgets/evaluation/liftcurve
   widgets/evaluation/predictions
   widgets/evaluation/rocanalysis
   widgets/evaluation/testandscore


.. toctree::
   :maxdepth: 1


